==> powerdevil-5.7.1.tar.xz: powerdevil-5.7.1/daemon/actions/bundled/suspendsessionconfig.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef POWERDEVIL_BUNDLEDACTIONS_SUSPENDSESSIONCONFIG_H
#define POWERDEVIL_BUNDLEDACTIONS_SUSPENDSESSIONCONFIG_H

#include <powerdevilactionconfig.h>

class KComboBox;
class QSpinBox;

namespace PowerDevil {
namespace BundledActions {

class SuspendSessionConfig : public PowerDevil::ActionConfig
{
    Q_OBJECT
    Q_DISABLE_COPY(SuspendSessionConfig)
public:
    SuspendSessionConfig(QObject* parent, const QVariantList&);
    virtual ~SuspendSessionConfig();

    virtual void save();
    virtual void load();
    virtual QList< QPair< QString, QWidget* > > buildUi();

private:
    QSpinBox *m_idleTime;
    KComboBox *m_comboBox;
};

}
}

#endif // POWERDEVIL_BUNDLEDACTIONS_SUSPENDSESSIONCONFIG_H

==> powerdevil_5.12.4.orig.tar.xz: powerdevil-5.12.4/daemon/actions/bundled/suspendsessionconfig.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef POWERDEVIL_BUNDLEDACTIONS_SUSPENDSESSIONCONFIG_H
#define POWERDEVIL_BUNDLEDACTIONS_SUSPENDSESSIONCONFIG_H

#include <powerdevilactionconfig.h>

class KComboBox;
class QSpinBox;

namespace PowerDevil {
namespace BundledActions {

class SuspendSessionConfig : public PowerDevil::ActionConfig
{
    Q_OBJECT
    Q_DISABLE_COPY(SuspendSessionConfig)
public:
    SuspendSessionConfig(QObject* parent, const QVariantList&);
    virtual ~SuspendSessionConfig();

    void save() Q_DECL_OVERRIDE;
    void load() Q_DECL_OVERRIDE;
    QList< QPair< QString, QWidget* > > buildUi() Q_DECL_OVERRIDE;

private:
    QSpinBox *m_idleTime;
    KComboBox *m_comboBox;
};

}
}

#endif // POWERDEVIL_BUNDLEDACTIONS_SUSPENDSESSIONCONFIG_H
